package com.gic.cloud.web.controller;

import com.gic.cloud.service.EnterprisePortraitRelApiService;
import com.gic.data.api.qo.member.*;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.gic.cloud.web.auth.DataAuthUtils;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.data.api.service.member.MemberCloudDataApiService;
import com.gic.enterprise.utils.ResultControllerUtils;

@RestController
public class MemberCloudDataController {
    private static final Logger log = LogManager.getLogger(MemberCloudDataController.class);
    @Autowired
    private MemberCloudDataApiService memberCloudDataApiService;
    @Autowired
    private StoreSearchUtils storeSearchUtils;
    @Autowired
    private DataAuthUtils dataAuthUtils;
    @Autowired
    private EnterprisePortraitRelApiService enterprisePortraitRelApiService;

    /**
     * 会员分布-趋势
     * @Title: queryMemberDistributionTrend 
     * @Description:
     * @author guojuxing
     * @param params 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
     */
    @RequestMapping("get-member-distribution-trend")
    public RestResponse queryMemberDistributionTrend(MemberDistributionTrendQO params) {
        log.info("会员分布-趋势参数：{}", JSON.toJSONString(params));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(memberCloudDataApiService.queryMemberDistributionTrend(params));
    }

    @RequestMapping("get-member-distribution-area")
    public RestResponse pageMemberDistributionArea(MemberDistributionAreaQO params) {
        log.info("会员分布-区域参数：{}", JSON.toJSONString(params));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        if (params.getLevel() == null) {
            params.setLevel(storeSearchUtils.getLevel(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()).getLevel());
        }
        params.setGroupIdList(storeSearchUtils.getChildrenStoreGroupIdList(params.getParentId()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(memberCloudDataApiService.pageMemberDistributionArea(params));
    }

    @RequestMapping("get-member-recruit-area")
    public RestResponse pageMemberRecruitArea(MemberRecruitAreaQO params) {
        log.info("会员招募-区域参数：{}", JSON.toJSONString(params));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        if (params.getLevel() == null) {
            params.setLevel(storeSearchUtils.getLevel(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()).getLevel());
        }
        params.setGroupIdList(storeSearchUtils.getChildrenStoreGroupIdList(params.getParentId()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(memberCloudDataApiService.pageMemberRecruitArea(params));
    }

    @RequestMapping("get-member-portrait")
    public RestResponse queryMemberBasicPortrait(MemberPortraitQO params) {
        log.info("会员基础画像参数：{}", JSON.toJSONString(params));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(memberCloudDataApiService.queryMemberBasicPortrait(params));
    }

    @RequestMapping("get-member-recruit-overview")
    public RestResponse getMemberRecruitOverview(MemberOverviewQO params) {
        log.info("会员概况-会员招募概况参数：{}", JSON.toJSONString(params));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(memberCloudDataApiService.getMemberRecruitOverview(params));
    }

    @RequestMapping("get-member-recruit-trend")
    public RestResponse queryMemberRecruitTrend(MemberOverviewQO params) {
        log.info("会员概况-会员招募趋势参数：{}", JSON.toJSONString(params));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(memberCloudDataApiService.queryMemberRecruitTrend(params));
    }


}
